ArxivLens
ArXiv cs.SE cs.SC

Performance of Buchberger's Improved Algorithm using Prime Based Ordering

0901.4404 Published Jan 29, 2009
Read paper View PDF
More tools
At a glance AI-generated · verify against the paper

This paper evaluates four versions of Buchberger's improved algorithm for computing Groebner Bases using prime-based ordering, finding significant reductions in computation time by replacing power product operations with integer operations. The study shows consistent performance improvements of 30% or more on tested polynomial sets.

Abstract

Prime-based ordering which is proved to be admissible, is the encoding of indeterminates in power-products with prime numbers and ordering them by using the natural number order. Using Eiffel, four versions of Buchberger's improved algorithm for obtaining Groebner Bases have been developed: two total degree versions, representing power products as strings and the other two as integers based on prime-based ordering. The versions are further distinguished by implementing coefficients as 64-bit integers and as multiple-precision integers. By using primebased power product coding, iterative or recursive operations on power products are replaced with integer operations. It is found that on a series of example polynomial sets, significant reductions in computation time of 30% or more are almost always obtained.

AI Key Findings

Get AI-generated insights about this paper's methodology, results, significance, and more — available when analysis has been generated.

Paper preview View the original document Preview of the original paper

How to Cite This Paper

Reference manager: RIS EndNote

Discussion 0

This website uses cookies to ensure you get the best experience. Learn more